@@ -1,7 +1,7 @@
 /*
     Qalculate    
 
-    Copyright (C) 2003-2006  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2003-2007  Niklas Knutsson (nq@altern.org)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -165,6 +165,8 @@ DECLARE_BUILTIN_FUNCTION(ExpFunction)
 DECLARE_BUILTIN_FUNCTION_R(LogFunction)
 DECLARE_BUILTIN_FUNCTION(LognFunction)
 
+DECLARE_BUILTIN_FUNCTION(LambertWFunction)
+
 DECLARE_BUILTIN_FUNCTION_R2(SinFunction)
 DECLARE_BUILTIN_FUNCTION_R2(CosFunction)
 DECLARE_BUILTIN_FUNCTION(TanFunction)
@@ -203,6 +205,9 @@ DECLARE_BUILTIN_FUNCTION(DayFunction)
 DECLARE_BUILTIN_FUNCTION(YearFunction)
 DECLARE_BUILTIN_FUNCTION(YeardayFunction)
 DECLARE_BUILTIN_FUNCTION(TimeFunction)
+DECLARE_BUILTIN_FUNCTION(AddDaysFunction)
+DECLARE_BUILTIN_FUNCTION(AddMonthsFunction)
+DECLARE_BUILTIN_FUNCTION(AddYearsFunction)
 
 DECLARE_BUILTIN_FUNCTION(BinFunction)
 DECLARE_BUILTIN_FUNCTION(OctFunction)
@@ -230,6 +235,14 @@ DECLARE_BUILTIN_FUNCTION(FunctionFunction)
 DECLARE_BUILTIN_FUNCTION(SelectFunction)
 DECLARE_BUILTIN_FUNCTION(TitleFunction)
 DECLARE_BUILTIN_FUNCTION(IFFunction)
+DECLARE_BUILTIN_FUNCTION(IsNumberFunction)
+DECLARE_BUILTIN_FUNCTION(IsRealFunction)
+DECLARE_BUILTIN_FUNCTION(IsRationalFunction)
+DECLARE_BUILTIN_FUNCTION(IsIntegerFunction)
+DECLARE_BUILTIN_FUNCTION(RepresentsNumberFunction)
+DECLARE_BUILTIN_FUNCTION(RepresentsRealFunction)
+DECLARE_BUILTIN_FUNCTION(RepresentsRationalFunction)
+DECLARE_BUILTIN_FUNCTION(RepresentsIntegerFunction)
 DECLARE_BUILTIN_FUNCTION(ErrorFunction)
 DECLARE_BUILTIN_FUNCTION(WarningFunction)
 DECLARE_BUILTIN_FUNCTION(MessageFunction)
