@@ -1,7 +1,7 @@
 /*
     Qalculate    
 
-    Copyright (C) 2004-2006  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2004-2007  Niklas Knutsson (nq@altern.org)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1944,6 +1944,41 @@ bool Number::exp() {
 	testInteger();
 	return true;
 }
+bool Number::lambertW() {
+	if(!isReal()) return false;
+	if(isZero()) return true;
+	cln::cl_R x = cln::realpart(value);
+	cln::cl_R m1_div_exp1 = -1 / cln::exp1();
+	if(x == m1_div_exp1) {
+		value = -1;
+		if(!b_approx) {
+			i_precision = PRECISION;
+			b_approx = true;
+		}
+		return true;
+	}
+	if(x < m1_div_exp1) return false;	
+	cln::cl_R w = 0;
+	if(x > 10) {
+		w = cln::ln(x) - cln::ln(cln::ln(x));
+	}
+	cln::cl_RA wPrec = cln::expt(cln::cl_I(10), -(PRECISION + 2));
+	while(true) {
+		cln::cl_R wTimesExpW = w * cln::exp(w);
+		cln::cl_R wPlusOneTimesExpW = (w + 1) * cln::exp(w);
+		if(wPrec > cln::abs((x - wTimesExpW) / wPlusOneTimesExpW)) {
+			value = w;
+			break;
+		}
+		w = w - (wTimesExpW - x) / (wPlusOneTimesExpW - (w + 2) * (wTimesExpW - x) / (2 * w + 2));
+	}
+	if(!b_approx) {
+		i_precision = PRECISION;
+		b_approx = true;
+	}
+	testInteger();
+	return true;
+}
 bool Number::gcd(const Number &o) {
 	if(!isInteger() || !o.isInteger()) {
 		return false;
@@ -2069,6 +2104,55 @@ bool Number::binomial(const Number &m, const Number &k) {
 	return true;
 }
 
+bool Number::factorize(vector<Number> &factors) {
+	if(isZero() || !isInteger()) return false;
+	cl_I inr = cln::numerator(cln::rational(cln::realpart(value)));
+	if(minusp(inr)) {
+		inr = -inr;
+		factors.push_back(Number(-1, 1));
+	}
+	size_t prime_index = 0;
+	cl_I last_prime = 0;
+	bool b = true;
+	while(b) {
+		b = false;
+		cl_I facmax = cln::floor1(cln::sqrt(inr));
+		for(; prime_index < NR_OF_PRIMES && PRIMES[prime_index] <= facmax; prime_index++) {
+			if(cln::zerop(cln::mod(inr, PRIMES[prime_index]))) {
+				inr = cln::exquo(inr, PRIMES[prime_index]);
+				Number fac;
+				fac.setInternal(PRIMES[prime_index]);
+				factors.push_back(fac);
+				b = true;
+				break;
+			}
+		}
+		if(prime_index == NR_OF_PRIMES) {
+			last_prime = PRIMES[NR_OF_PRIMES - 1] + 2;
+			prime_index++;
+		}
+		if(!b && prime_index > NR_OF_PRIMES) {
+			while(!b && last_prime <= facmax) {
+				if(cln::zerop(cln::mod(inr, last_prime))) {
+					inr = cln::exquo(inr, last_prime);
+					b = true;
+					Number fac;
+					fac.setInternal(last_prime);
+					factors.push_back(fac);
+					break;
+				}
+				last_prime = last_prime + 2;
+			}
+		}
+	}
+	if(inr != 1) {
+		Number fac;
+		fac.setInternal(inr);
+		factors.push_back(fac);
+	}
+	return true;
+}
+
 bool Number::add(const Number &o, MathOperation op) {
 	switch(op) {
 		case OPERATION_SUBTRACT: {
@@ -2393,10 +2477,12 @@ string Number::print(const PrintOptions &po, const InternalPrintStruct &ips) con
 			}
 		}
 
-		if(po.min_exp < 0) {
+		if(po.min_exp == EXP_PRECISION) {
 			if((expo > -precision && expo < precision) || (expo < 3 && expo > -3 && PRECISION >= 3)) { 
 				expo = 0;
 			}
+		} else if(po.min_exp == EXP_BASE_3) {
+			expo -= expo % 3;
 		} else if(po.min_exp != 0) {
 			if(expo > -po.min_exp && expo < po.min_exp) { 
 				expo = 0;
@@ -2598,10 +2684,12 @@ string Number::print(const PrintOptions &po, const InternalPrintStruct &ips) con
 					expo = 0;
 				} else {
 					expo = str.length() - 1;
-					if(po.min_exp < 0) {
+					if(po.min_exp == EXP_PRECISION) {
 						if((expo > -precision && expo < precision) || (expo < 3 && expo > -3 && PRECISION >= 3)) { 
 							expo = 0;
 						}
+					} else if(po.min_exp == EXP_BASE_3) {
+						expo -= expo % 3;
 					} else if(po.min_exp != 0) {
 						if(expo > -po.min_exp && expo < po.min_exp) { 
 							expo = 0;
@@ -2710,10 +2798,12 @@ string Number::print(const PrintOptions &po, const InternalPrintStruct &ips) con
 			str = printCL_I(num, base, true, BASE_DISPLAY_NONE, po.lower_case_numbers);
 			if(base == 10) {
 				expo = str.length() - l10 - 1;
-				if(po.min_exp < 0) {
+				if(po.min_exp == EXP_PRECISION) {
 					if((expo > -precision && expo < precision) || (expo < 3 && expo > -3 && PRECISION >= 3)) { 
 						expo = 0;
 					}
+				} else if(po.min_exp == EXP_BASE_3) {
+					expo -= expo % 3;
 				} else if(po.min_exp != 0) {
 					if(expo > -po.min_exp && expo < po.min_exp) { 
 						expo = 0;
